@@ -19,21 +19,21 @@ use crate::{Error, Result, SignerInfo};
 /// If data_dir is provided, any thumbnail or c2pa data will be written to that folder.
 /// Any Validation errors will be reported in the validation_status field.
 ///
-pub fn verify_from_file_json(path: &str, data_dir: Option<String>) -> Result<String> {
+pub fn read_file(path: &str, data_dir: Option<String>) -> Result<String> {
     Ok(match data_dir {
         Some(dir) => ManifestStore::from_file_with_resources(path, &dir),
         None => ManifestStore::from_file(path),
     }
-    .map_err(Error::Sdk)?
+    .map_err(Error::from_c2pa_error)?
     .to_string())
 }
 
 /// Returns an Ingredient JSON string from a file path.
 ///
 /// Any thumbnail or c2pa data will be written to data_dir if provided
-pub fn ingredient_from_file_json(path: &str, data_dir: &str) -> Result<String> {
+pub fn read_ingredient_file(path: &str, data_dir: &str) -> Result<String> {
     Ok(Ingredient::from_file_with_folder(path, data_dir)
-        .map_err(Error::Sdk)?
+        .map_err(Error::from_c2pa_error)?
         .to_string())
 }
 
@@ -43,30 +43,36 @@ pub fn ingredient_from_file_json(path: &str, data_dir: &str) -> Result<String> {
 /// Signer information must also be supplied
 ///
 /// Any file paths in the manifest will be read relative to the source file
-pub fn add_manifest_to_file_json(
+pub fn sign_file(
     source: &str,
     dest: &str,
-    manifest_info: &str,
-    signer_info: SignerInfo,
+    manifest_json: &str,
+    signer_info: &SignerInfo,
     data_dir: Option<String>,
 ) -> Result<Vec<u8>> {
-    let mut manifest = Manifest::from_json(manifest_info).map_err(Error::Sdk)?;
+    let mut manifest = Manifest::from_json(manifest_json).map_err(Error::from_c2pa_error)?;
 
     // if data_dir is provided, set the base path for the manifest
     if let Some(path) = data_dir {
-        manifest.with_base_path(path).map_err(Error::Sdk)?;
+        manifest
+            .with_base_path(path)
+            .map_err(Error::from_c2pa_error)?;
     }
 
     // If the source file has a manifest store, and no parent is specified, treat the source's manifest store as the parent.
     if manifest.parent().is_none() {
-        let source_ingredient = Ingredient::from_file(source).map_err(Error::Sdk)?;
+        let source_ingredient = Ingredient::from_file(source).map_err(Error::from_c2pa_error)?;
         if source_ingredient.manifest_data().is_some() {
-            manifest.set_parent(source_ingredient).map_err(Error::Sdk)?;
+            manifest
+                .set_parent(source_ingredient)
+                .map_err(Error::from_c2pa_error)?;
         }
     }
 
     let signer = signer_info.signer()?;
-    manifest.embed(&source, &dest, &*signer).map_err(Error::Sdk)
+    manifest
+        .embed(&source, &dest, &*signer)
+        .map_err(Error::from_c2pa_error)
 }
 
 #[cfg(test)]
@@ -83,20 +89,22 @@ mod tests {
     #[test]
     fn test_verify_from_file_no_base() {
         let path = test_path("tests/fixtures/C.jpg");
-        let result = verify_from_file_json(&path, None);
+        let result = read_file(&path, None);
         assert!(result.is_ok());
         let json_report = result.unwrap();
         println!("{}", json_report);
         assert!(json_report.contains("C.jpg"));
-        //assert!(!json_report.contains("validation_status"));
+        assert!(!json_report.contains("validation_status"));
     }
 
     #[test]
-    fn test_verify_from_file_with_base() {
+    fn test_read_from_file_with_base() {
         let path = test_path("tests/fixtures/C.jpg");
         let data_dir = "target/data_dir";
-        remove_dir_all(data_dir).unwrap();
-        let result = verify_from_file_json(&path, Some(data_dir.to_owned()));
+        if PathBuf::from(data_dir).exists() {
+            remove_dir_all(data_dir).unwrap();
+        }
+        let result = read_file(&path, Some(data_dir.to_owned()));
         assert!(result.is_ok());
         let json_report = result.unwrap();
         println!("{}", json_report);
